function [prof_dist, prof_trans, ptv] = project_profile(llh_origin, az, width, llh, enu)


% scale width from km to meters

width = width*1000;

nvec = length(llh);
prof_dist = zeros(1,nvec);
prof_trans = zeros(1,nvec);
ptv = zeros(3,nvec);

baseline_enu = zeros(3,nvec);
dxyz = zeros(3,1);
tdist = zeros(3,nvec);

%   Compute the vectors from the origin (LLH) to
%         each point in the local ENU system of the origin.
%

xyzref = llh2xyz(llh_origin);

for j = 1:nvec
    xyz    = llh2xyz(llh(:,j));
    dxyz(:,1) = xyz - xyzref;
    k = 3*(j - 1);
    baseline_enu(k+1:k+3,1) = xyz2enu(llh_origin, dxyz);
end


%    Rotate the vectors to the PTV system defined
%        by the azimuth AZ
%
%  Compute the transformation matrix based on the azimuth

deg2rad = pi/180;
if (az < 0)
   az = az + 360;
end
if (az >= 180)
   az = az - 180;
end
theta = 90 - az;

%  Form the matrix

stheta = sin(theta*deg2rad);
ctheta = cos(theta*deg2rad);

t = [ctheta, stheta, 0; -stheta, ctheta, 0; 0, 0, 1];

for ista = 1:nvec,
   k = 3*(ista - 1);
   tdist(:,ista) = t*baseline_enu(k+1:k+3,1);
   
   ptv(:,ista) = t*enu(:,ista);
   prof_dist(ista) = tdist(1,ista);
   prof_trans(ista) = tdist(2,ista);
end

% Select sites within specified width of the profile

idx = find(abs(prof_trans) < width/2);
prof_dist  = prof_dist(idx);
prof_trans = prof_trans(idx);
ptv        = ptv(:,idx);



