%Change these values to get the best fit
% Shift X and Y origin to get the mogi model to line up
originx = 0e3; %values in meters
originy = 0e3; % values in meters
%Shift depth
depth = 13e3; % values in meters
% Shift volume change
dV = 6e7; % values in cubic m


look = 23*pi/180;
heading=(-167+90)*pi/180;

s_uv1 = [sin(heading).*sin(look)].*ones(size(x));  
s_uv2 = [cos(heading).*sin(look)].*ones(size(x));
s_uv3 = [ -cos(look)].*ones(size(x));

profilex = 77;
profiley = 52;

[los] = calc_mogi(x,y,originx,originy,depth,dV,s_uv1,s_uv2,s_uv3);

good = find(isnan(hualca) ==0);
misfit = std(hualca(good)+los(good));

figure
subplot(2,3,1)
pcolor(x/1e3,y/1e3,hualca)
shading flat
axis image
h=caxis;
hold on
plot(x(profilex,:)/1e3,y(profilex,:)/1e3,'k-')
plot(x(:,profiley)/1e3,y(:,profiley)/1e3,'k-')
xlabel('East (km)')
ylabel('North (km)')
subplot(2,3,2)
pcolor(x/1e3,y/1e3,-los)
hold on
plot(x(profilex,:)/1e3,y(profilex,:)/1e3,'k-')
plot(x(:,profiley)/1e3,y(:,profiley)/1e3,'k-')
shading flat
axis image
caxis([h])
colorbar
xlabel('East (km)')
ylabel('North (km)')
subplot(2,3,3)
pcolor(x/1e3,y/1e3,hualca+los)
hold on
plot(x(profilex,:)/1e3,y(profilex,:)/1e3,'k-')
plot(x(:,profiley)/1e3,y(:,profiley)/1e3,'k-')
shading flat
axis image
caxis([-.015 .015])
colorbar
xlabel('East (km)')
ylabel('North (km)')
subplot(2,3,4)
plot(x(profilex,:)/1e3,-los(profilex,:),'k.')
hold on
plot(x(profilex,:)/1e3,hualca(profilex,:),'r.')
xlabel('East (km)')
ylabel('Displacement (m)')
subplot(2,3,5)
plot(y(:,profiley)/1e3,-los(:,profiley),'k.')
hold on
plot(y(:,profiley)/1e3,hualca(:,profiley),'r.')
xlabel('North (km)')
ylabel('Displacement (m)')
subplot(2,3,6)
plot(y(:,profiley)/1e3,hualca(:,profiley)+los(:,profiley),'k.')
hold on
plot(x(profilex,:)/1e3,hualca(profilex,:)+los(profilex,:),'r.')
xlabel('North or East (km)')
ylabel('Residual (m)')
set(gcf,'position',[12  243   1180    455])
suptitle(['Misfit=  ' num2str(misfit*1e2) '(cm); Depth=  ' num2str(depth/1e3) '(km); X=  ' num2str(originx/1e3) '(km); Y=  ' num2str(originy/1e3) '(km); dV=  ' num2str(dV/1e6) '(10^6 m^3);'])



